==> coos.app-2.0.6-sources.jar: top/coos/app/bean/service/DatabaseServiceFieldBean.java <==
package top.coos.app.bean.service;

import top.coos.app.enums.ComparisonOperator;

public class DatabaseServiceFieldBean extends ServiceFieldBean {

	private String tableid;

	private String columnid;

	private String relatedcolumnid;

	private String relatedtableid;

	private String relatedtablecolumnid;

	private String customsql;

	private String customfunction;

	private ComparisonOperator comparisonoperator;

	private boolean forselect;

	private boolean forwhere;

	private boolean forupdate;

	private boolean fororder;

	private boolean forgroup;

	public ComparisonOperator getComparisonoperator() {

		return comparisonoperator;
	}

	public void setComparisonoperator(ComparisonOperator comparisonoperator) {

		this.comparisonoperator = comparisonoperator;
	}

	public String getCustomfunction() {

		return customfunction;
	}

	public void setCustomfunction(String customfunction) {

		this.customfunction = customfunction;
	}

	public String getCustomsql() {

		return customsql;
	}

	public void setCustomsql(String customsql) {

		this.customsql = customsql;
	}

	public String getRelatedtablecolumnid() {

		return relatedtablecolumnid;
	}

	public void setRelatedtablecolumnid(String relatedtablecolumnid) {

		this.relatedtablecolumnid = relatedtablecolumnid;
	}

	public String getRelatedtableid() {

		return relatedtableid;
	}

	public void setRelatedtableid(String relatedtableid) {

		this.relatedtableid = relatedtableid;
	}

	public String getRelatedcolumnid() {

		return relatedcolumnid;
	}

	public void setRelatedcolumnid(String relatedcolumnid) {

		this.relatedcolumnid = relatedcolumnid;
	}

	public boolean isFororder() {

		return fororder;
	}

	public void setFororder(boolean fororder) {

		this.fororder = fororder;
	}

	public boolean isForgroup() {

		return forgroup;
	}

	public void setForgroup(boolean forgroup) {

		this.forgroup = forgroup;
	}

	public boolean isForwhere() {

		return forwhere;
	}

	public void setForwhere(boolean forwhere) {

		this.forwhere = forwhere;
	}

	public boolean isForupdate() {

		return forupdate;
	}

	public void setForupdate(boolean forupdate) {

		this.forupdate = forupdate;
	}

	public boolean isForselect() {

		return forselect;
	}

	public void setForselect(boolean forselect) {

		this.forselect = forselect;
	}

	private boolean notusecolumndefaultvalue;

	public boolean isNotusecolumndefaultvalue() {

		return notusecolumndefaultvalue;
	}

	public void setNotusecolumndefaultvalue(boolean notusecolumndefaultvalue) {

		this.notusecolumndefaultvalue = notusecolumndefaultvalue;
	}

	public String getTableid() {

		return tableid;
	}

	public void setTableid(String tableid) {

		this.tableid = tableid;
	}

	public String getColumnid() {

		return columnid;
	}

	public void setColumnid(String columnid) {

		this.columnid = columnid;
	}

}

==> coos.app-2.2.3.5-sources.jar: top/coos/app/bean/service/DatabaseServiceFieldBean.java <==
package top.coos.app.bean.service;

import top.coos.app.enums.ComparisonOperator;

public class DatabaseServiceFieldBean extends ServiceFieldBean {

	private String tableid;

	private String columnid;

	private String relatedcolumnid;

	private String relatedtableid;

	private String relatedtablecolumnid;

	private String customsql;

	private String customfunction;

	private ComparisonOperator comparisonoperator;

	private boolean forselect;

	private boolean forwhere;

	private boolean forinsert;

	private boolean forupdate;

	private boolean fororder;

	private boolean forgroup;

	public ComparisonOperator getComparisonoperator() {

		return comparisonoperator;
	}

	public void setComparisonoperator(ComparisonOperator comparisonoperator) {

		this.comparisonoperator = comparisonoperator;
	}

	public String getCustomfunction() {

		return customfunction;
	}

	public void setCustomfunction(String customfunction) {

		this.customfunction = customfunction;
	}

	public String getCustomsql() {

		return customsql;
	}

	public void setCustomsql(String customsql) {

		this.customsql = customsql;
	}

	public String getRelatedtablecolumnid() {

		return relatedtablecolumnid;
	}

	public void setRelatedtablecolumnid(String relatedtablecolumnid) {

		this.relatedtablecolumnid = relatedtablecolumnid;
	}

	public String getRelatedtableid() {

		return relatedtableid;
	}

	public void setRelatedtableid(String relatedtableid) {

		this.relatedtableid = relatedtableid;
	}

	public String getRelatedcolumnid() {

		return relatedcolumnid;
	}

	public void setRelatedcolumnid(String relatedcolumnid) {

		this.relatedcolumnid = relatedcolumnid;
	}

	public boolean isFororder() {

		return fororder;
	}

	public void setFororder(boolean fororder) {

		this.fororder = fororder;
	}

	public boolean isForgroup() {

		return forgroup;
	}

	public void setForgroup(boolean forgroup) {

		this.forgroup = forgroup;
	}

	public boolean isForwhere() {

		return forwhere;
	}

	public void setForwhere(boolean forwhere) {

		this.forwhere = forwhere;
	}

	public boolean isForinsert() {

		return forinsert;
	}

	public void setForinsert(boolean forinsert) {

		this.forinsert = forinsert;
	}

	public boolean isForupdate() {

		return forupdate;
	}

	public void setForupdate(boolean forupdate) {

		this.forupdate = forupdate;
	}

	public boolean isForselect() {

		return forselect;
	}

	public void setForselect(boolean forselect) {

		this.forselect = forselect;
	}

	private boolean notusecolumndefaultvalue;

	public boolean isNotusecolumndefaultvalue() {

		return notusecolumndefaultvalue;
	}

	public void setNotusecolumndefaultvalue(boolean notusecolumndefaultvalue) {

		this.notusecolumndefaultvalue = notusecolumndefaultvalue;
	}

	public String getTableid() {

		return tableid;
	}

	public void setTableid(String tableid) {

		this.tableid = tableid;
	}

	public String getColumnid() {

		return columnid;
	}

	public void setColumnid(String columnid) {

		this.columnid = columnid;
	}

}
